@@ -6,12 +6,13 @@ using System.Runtime.InteropServices;
 using System.Text;
 using Mono.Unix;
 using Gtk;
+
 namespace Tomboy
 {
 	public class NoteWindow : ForcedPresentWindow
 	{
 		Note note;
-		
+
 		Gtk.AccelGroup accel_group;
 		Gtk.Toolbar toolbar;
 		Gtk.Tooltips toolbar_tips;
@@ -33,8 +34,8 @@ namespace Tomboy
 		// and a Gtk.TextView as the body.
 		//
 
-public NoteWindow (Note note) :
-		base (note.Title)
+		public NoteWindow (Note note)
+			: base (note.Title)
 		{
 			this.note = note;
 			this.IconName = "tomboy";
@@ -106,7 +107,7 @@ public NoteWindow (Note note) :
 			// Don't set up Ctrl-W or Ctrl-N if Emacs is in use
 			bool using_emacs = false;
 			string gtk_key_theme = (string)
-			                       Preferences.Get ("/desktop/gnome/interface/gtk_key_theme");
+				Preferences.Get ("/desktop/gnome/interface/gtk_key_theme");
 			if (gtk_key_theme != null && gtk_key_theme.CompareTo ("Emacs") == 0)
 				using_emacs = true;
 
@@ -159,7 +160,12 @@ public NoteWindow (Note note) :
 				                            Gtk.AccelFlags.Visible);
 
 			// Have Esc key close the note window
-			KeyPressEvent += KeyPressed;
+			if ((bool) Preferences.Get (Preferences.ENABLE_CLOSE_NOTE_ON_ESCAPE))
+				KeyPressEvent += KeyPressed;
+
+			// Watch the escape setting in GConf
+			Preferences.Client.AddNotify (Preferences.ENABLE_CLOSE_NOTE_ON_ESCAPE,
+					OnEscapeSettingChanged);
 
 			// Increase Indent
 			global_keys.AddAccelerator (new EventHandler (ChangeDepthRightHandler),
@@ -174,7 +180,6 @@ public NoteWindow (Note note) :
 			                            Gtk.AccelFlags.Visible);
 
 			this.Add (box);
-			
 		}
 
 		protected override bool OnDeleteEvent (Gdk.Event evnt)
@@ -195,6 +200,16 @@ public NoteWindow (Note note) :
 			Move (x, y);
 		}
 
+		void OnEscapeSettingChanged (object sender, GConf.NotifyEventArgs args)
+		{
+			// enable escape key
+			if ((bool) args.Value)
+				KeyPressEvent += KeyPressed;
+			// disable escape key
+			else
+				KeyPressEvent -= KeyPressed;
+		}
+
 		void KeyPressed (object sender, Gtk.KeyPressEventArgs args)
 		{
 			args.RetVal = true;
@@ -236,7 +251,7 @@ public NoteWindow (Note note) :
 				// Close windows on the same workspace, or all
 				// open windows if no workspace.
 				if (workspace < 0 ||
-				                tomboy_window_get_workspace (iter.Window.Handle) == workspace) {
+				    tomboy_window_get_workspace (iter.Window.Handle) == workspace) {
 					iter.Window.CloseWindowHandler (null, null);
 				}
 			}
@@ -249,7 +264,9 @@ public NoteWindow (Note note) :
 		void OnDeleteButtonClicked (object sender, EventArgs args)
 		{
 			// Prompt for note deletion
-			NoteUtils.ShowDeletionDialog (note, this);
+			List<Note> single_note_list = new List<Note> (1);
+			single_note_list.Add (note);
+			NoteUtils.ShowDeletionDialog (single_note_list, this);
 		}
 
 		//
@@ -267,7 +284,7 @@ public NoteWindow (Note note) :
 				return toolbar;
 			}
 		}
-		
+
 		/// <summary>
 		/// The Delete Toolbar Button
 		/// </summary>
@@ -290,6 +307,12 @@ public NoteWindow (Note note) :
 			}
 		}
 
+		public Gtk.AccelGroup AccelGroup {
+			get {
+				return accel_group;
+			}
+		}
+
 		//
 		// Sensitize the Link toolbar button on text selection
 		//
@@ -411,10 +434,13 @@ public NoteWindow (Note note) :
 		{
 			Gtk.Toolbar tb = new Gtk.Toolbar ();
 			tb.Tooltips = true;
-			
+
 			toolbar_tips = new Gtk.Tooltips ();
-			
-			Gtk.ToolButton search = new Gtk.ToolButton (new Gtk.Image (Gtk.Stock.Find, tb.IconSize), Catalog.GetString ("Search"));
+
+			Gtk.ToolButton search = new Gtk.ToolButton (
+				new Gtk.Image (Gtk.Stock.Find, tb.IconSize),
+				Catalog.GetString ("Search"));
+			search.IsImportant = true;
 			search.Clicked += SearchActivate;
 			toolbar_tips.SetTip (search, Catalog.GetString ("Search your notes (Ctrl-Shift-F)"), null);
 			search.AddAccelerator ("clicked",
@@ -425,11 +451,17 @@ public NoteWindow (Note note) :
 			                       Gtk.AccelFlags.Visible);
 			search.ShowAll ();
 			tb.Insert (search, -1);
-			
-			link_button = new Gtk.ToolButton (new Gtk.Image (Gtk.Stock.JumpTo, tb.IconSize), Catalog.GetString ("Link"));
+
+			link_button = new Gtk.ToolButton (
+				new Gtk.Image (Gtk.Stock.JumpTo, tb.IconSize),
+				Catalog.GetString ("Link"));
+			link_button.IsImportant = true;
 			link_button.Sensitive = (note.Buffer.Selection != null);
 			link_button.Clicked += LinkToNoteActivate;
-			toolbar_tips.SetTip (link_button, Catalog.GetString ("Link selected text to a new note (Ctrl-L)"), null);
+			toolbar_tips.SetTip (
+				link_button,
+				Catalog.GetString ("Link selected text to a new note (Ctrl-L)"),
+				null);
 			link_button.AddAccelerator ("clicked",
 			                            accel_group,
 			                            (uint) Gdk.Key.l,
@@ -437,16 +469,17 @@ public NoteWindow (Note note) :
 			                            Gtk.AccelFlags.Visible);
 			link_button.ShowAll ();
 			tb.Insert (link_button, -1);
-			
+
 			ToolMenuButton text_button =
 			        new ToolMenuButton (tb,
 			                            Gtk.Stock.SelectFont,
 			                            Catalog.GetString ("_Text"),
 			                            text_menu);
+			text_button.IsImportant = true;
 			text_button.ShowAll ();
 			tb.Insert (text_button, -1);
 			toolbar_tips.SetTip (text_button, Catalog.GetString ("Set properties of text"), null);
-			
+
 			ToolMenuButton plugin_button =
 			        new ToolMenuButton (tb,
 			                            Gtk.Stock.Execute,
@@ -455,28 +488,28 @@ public NoteWindow (Note note) :
 			plugin_button.ShowAll ();
 			tb.Insert (plugin_button, -1);
 			toolbar_tips.SetTip (plugin_button, Catalog.GetString ("Use tools on this note"), null);
-			
+
 			tb.Insert (new Gtk.SeparatorToolItem (), -1);
-			
+
 			delete = new Gtk.ToolButton (Gtk.Stock.Delete);
 			delete.Clicked += OnDeleteButtonClicked;
 			delete.ShowAll ();
 			tb.Insert (delete, -1);
 			toolbar_tips.SetTip (delete, Catalog.GetString ("Delete this note"), null);
-			
+
 			// Don't allow deleting the "Start Here" note...
 			if (note.IsSpecial)
 				delete.Sensitive = false;
 
 			tb.Insert (new Gtk.SeparatorToolItem (), -1);
-			
+
 			Gtk.ImageMenuItem item =
 			        new Gtk.ImageMenuItem (Catalog.GetString ("Synchronize Notes"));
 			item.Image = new Gtk.Image (Gtk.Stock.Convert, Gtk.IconSize.Menu);
 			item.Activated += SyncItemSelected;
 			item.Show ();
 			PluginMenu.Add (item);
-			
+
 			tb.ShowAll ();
 			return tb;
 		}
@@ -684,7 +717,6 @@ public NoteWindow (Note note) :
 		Gtk.Entry entry;
 		Gtk.Button next_button;
 		Gtk.Button prev_button;
-		Gtk.CheckButton case_sensitive;
 
 		ArrayList current_matches;
 		string prev_search_text;
@@ -694,7 +726,8 @@ public NoteWindow (Note note) :
 
 		bool shift_key_pressed;
 
-public NoteFindBar (Note note) : base (false, 0)
+		public NoteFindBar (Note note)
+			: base (false, 0)
 		{
 			this.note = note;
 
@@ -736,12 +769,6 @@ public NoteFindBar (Note note) : base (false, 0)
 			next_button.Show ();
 			PackStart (next_button, false, false, 0);
 
-			case_sensitive = new Gtk.CheckButton (
-			        Catalog.GetString ("Case _sensitive"));
-			case_sensitive.Toggled += OnCaseSensitiveToggled;
-			case_sensitive.Show ();
-			PackStart (case_sensitive, true, true, 0);
-
 			// Bind ESC to close the FindBar if it's open and has
 			// focus or the window otherwise.  Also bind Return and
 			// Shift+Return to advance the search if the search
@@ -841,11 +868,6 @@ public NoteFindBar (Note note) : base (false, 0)
 			editor.ScrollMarkOnscreen (buffer.InsertMark);
 		}
 
-		void OnCaseSensitiveToggled (object sender, EventArgs args)
-		{
-			PerformSearch (true);
-		}
-
 		void OnFindEntryActivated (object sender, EventArgs args)
 		{
 			if (entry_changed_timeout != null) {
@@ -895,15 +917,12 @@ public NoteFindBar (Note note) : base (false, 0)
 			if (text == null)
 				return;
 
-			if (!case_sensitive.Active)
-				text = text.ToLower ();
+			text = text.ToLower ();
 
 			string [] words = text.Split (' ', '\t', '\n');
 
 			current_matches =
-			        FindMatchesInBuffer (note.Buffer,
-			                             words,
-			                             case_sensitive.Active);
+			        FindMatchesInBuffer (note.Buffer, words);
 
 			prev_search_text = SearchText;
 
@@ -1082,15 +1101,14 @@ public NoteFindBar (Note note) : base (false, 0)
 			UpdateSensitivity ();
 		}
 
-		ArrayList FindMatchesInBuffer (NoteBuffer buffer, string [] words, bool match_case)
+		ArrayList FindMatchesInBuffer (NoteBuffer buffer, string [] words)
 		{
 			ArrayList matches = new ArrayList ();
 
 			string note_text = buffer.GetSlice (buffer.StartIter,
 			                                    buffer.EndIter,
 			                                    false /* hidden_chars */);
-			if (!match_case)
-				note_text = note_text.ToLower ();
+			note_text = note_text.ToLower ();
 
 			foreach (string word in words) {
 				int idx = 0;
@@ -1181,7 +1199,7 @@ public NoteFindBar (Note note) : base (false, 0)
 		public NoteTextMenu (Gtk.AccelGroup accel_group,
 		                     NoteBuffer     buffer,
 		                     UndoManager    undo_manager)
-: base ()
+			: base ()
 		{
 			this.buffer = buffer;
 			this.undo_manager = undo_manager;
